==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/main/dialogs/changeframeratedialog.h <==
#ifndef CHANGEFRAMERATEDIALOG_H
#define CHANGEFRAMERATEDIALOG_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include "actiondialog.h"

class KComboBox;

namespace SubtitleComposer
{
	class ChangeFrameRateDialog : public ActionDialog
	{
		public:

			ChangeFrameRateDialog( double fromFramesPerSecond, QWidget* parent=0 );

			double fromFramesPerSecond();
			void setFromFramesPerSecond( double framesPerSecond );

			double toFramesPerSecond();
			void setNewFramesPerSecond( double framesPerSecond );

		protected:

			virtual void accept();

		private:

			KComboBox* m_fromFramesPerSecondComboBox;
			KComboBox* m_toFramesPerSecondComboBox;
	};
}

#endif

==> subtitlecomposer-0.4.3.tar.bz2: subtitlecomposer-0.4.3/src/main/dialogs/changeframeratedialog.h <==
#ifndef CHANGEFRAMERATEDIALOG_H
#define CHANGEFRAMERATEDIALOG_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include "actiondialog.h"

class KComboBox;

namespace SubtitleComposer
{
	class ChangeFrameRateDialog : public ActionDialog
	{
		public:

			ChangeFrameRateDialog( double fromFramesPerSecond, QWidget* parent=0 );

			double fromFramesPerSecond() const;
			void setFromFramesPerSecond( double framesPerSecond );

			double toFramesPerSecond() const;
			void setNewFramesPerSecond( double framesPerSecond );

		protected:

			virtual void accept();

		private:

			KComboBox* m_fromFramesPerSecondComboBox;
			KComboBox* m_toFramesPerSecondComboBox;
	};
}

#endif
